@@ -53,6 +53,9 @@ ASSERT_ENUM (GGIT_DELTA_RENAMED,    GIT_DELTA_RENAMED);
 ASSERT_ENUM (GGIT_DELTA_COPIED,     GIT_DELTA_COPIED);
 ASSERT_ENUM (GGIT_DELTA_IGNORED,    GIT_DELTA_IGNORED);
 ASSERT_ENUM (GGIT_DELTA_UNTRACKED,  GIT_DELTA_UNTRACKED);
+ASSERT_ENUM (GGIT_DELTA_TYPECHANGE, GIT_DELTA_TYPECHANGE);
+ASSERT_ENUM (GGIT_DELTA_UNREADABLE, GIT_DELTA_UNREADABLE);
+ASSERT_ENUM (GGIT_DELTA_CONFLICTED, GIT_DELTA_CONFLICTED);
 
 ASSERT_ENUM (GGIT_DIFF_FORMAT_PATCH,         GIT_DIFF_FORMAT_PATCH);
 ASSERT_ENUM (GGIT_DIFF_FORMAT_PATCH_HEADER,  GIT_DIFF_FORMAT_PATCH_HEADER);
@@ -179,7 +182,10 @@ ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_NEW,        GIT_STATUS_WT_NEW);
 ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_MODIFIED,   GIT_STATUS_WT_MODIFIED);
 ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_DELETED,    GIT_STATUS_WT_DELETED);
 ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_TYPECHANGE, GIT_STATUS_WT_TYPECHANGE);
+ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_RENAMED,    GIT_STATUS_WT_RENAMED);
+ASSERT_ENUM (GGIT_STATUS_WORKING_TREE_UNREADABLE, GIT_STATUS_WT_UNREADABLE);
 ASSERT_ENUM (GGIT_STATUS_IGNORED,                 GIT_STATUS_IGNORED);
+ASSERT_ENUM (GGIT_STATUS_CONFLICTED,              GIT_STATUS_CONFLICTED);
 
 
 ASSERT_ENUM (GGIT_SUBMODULE_IGNORE_UNSPECIFIED, GIT_SUBMODULE_IGNORE_UNSPECIFIED);
