@@ -25,6 +25,13 @@
 
 G_BEGIN_DECLS
 
+/**
+ * GgitAnnotatedCommit:
+ *
+ * Represents an annotated commit object.
+ */
+typedef struct _GgitAnnotatedCommit GgitAnnotatedCommit;
+
 /**
  * GgitBranchEnumerator:
  *
@@ -172,6 +179,27 @@ typedef struct _GgitOId GgitOId;
  */
 typedef struct _GgitPatch GgitPatch;
 
+/**
+ * GgitRebaseOperation:
+ *
+ * Represents a rebase operation.
+ */
+typedef struct _GgitRebaseOperation GgitRebaseOperation;
+
+/**
+ * GgitRebaseOptions:
+ *
+ * Represents the options used when rebasing.
+ */
+typedef struct _GgitRebaseOptions GgitRebaseOptions;
+
+/**
+ * GgitRef:
+ *
+ * Reprensents a git reference.
+ */
+typedef struct _GgitRef GgitRef;
+
 /**
  * GgitRefSpec:
  *
@@ -308,10 +336,12 @@ typedef enum
 
 /**
  * GgitConfigLevel:
+ * @GGIT_CONFIG_LEVEL_PROGRAMDATA: System-wide on Windows, for compatibility with portable git.
  * @GGIT_CONFIG_LEVEL_SYSTEM: System-wide configuration file.
  * @GGIT_CONFIG_LEVEL_XDG: XDG compatible configuration file (.config/git/config).
  * @GGIT_CONFIG_LEVEL_GLOBAL: User-specific configuration file, also called Global configuration file.
  * @GGIT_CONFIG_LEVEL_LOCAL: Repository specific configuration file.
+ * @GGIT_CONFIG_LEVEL_APP: Application specific configuration file; freely defined by applications.
  * @GGIT_CONFIG_LEVEL_HIGHEST: Represents the highest level of a config file.
  *
  * Priority level of a config file.
@@ -320,11 +350,13 @@ typedef enum
  */
 typedef enum
 {
-	GGIT_CONFIG_LEVEL_SYSTEM  = 1,
-	GGIT_CONFIG_LEVEL_XDG     = 2,
-	GGIT_CONFIG_LEVEL_GLOBAL  = 3,
-	GGIT_CONFIG_LEVEL_LOCAL   = 4,
-	GGIT_CONFIG_LEVEL_HIGHEST = -1
+	GGIT_CONFIG_LEVEL_PROGRAMDATA = 1,
+	GGIT_CONFIG_LEVEL_SYSTEM      = 2,
+	GGIT_CONFIG_LEVEL_XDG         = 3,
+	GGIT_CONFIG_LEVEL_GLOBAL      = 4,
+	GGIT_CONFIG_LEVEL_LOCAL       = 5,
+	GGIT_CONFIG_LEVEL_APP         = 6,
+	GGIT_CONFIG_LEVEL_HIGHEST     = -1
 } GgitConfigLevel;
 
 /**
@@ -361,7 +393,11 @@ typedef enum {
 	GGIT_DELTA_RENAMED    = 4,
 	GGIT_DELTA_COPIED     = 5,
 	GGIT_DELTA_IGNORED    = 6,
-	GGIT_DELTA_UNTRACKED  = 7
+	GGIT_DELTA_UNTRACKED  = 7,
+	GGIT_DELTA_TYPECHANGE = 8,
+	GGIT_DELTA_UNREADABLE = 9,
+	GGIT_DELTA_CONFLICTED = 10,
+
 } GgitDeltaType;
 
 /**
@@ -410,6 +446,7 @@ typedef enum {
  * @GGIT_DIFF_SHOW_UNMODIFIED: show unmodified files.
  * @GGIT_DIFF_PATIENCE: generate using the "patience diff" algorithm.
  * @GGIT_DIFF_MINIMAL: take extra time to find minimal diff.
+ * @GGIT_DIFF_SHOW_BINARY: include deflate/delta information for binary files.
  *
  * How the diff should be generated.
  */
@@ -441,7 +478,8 @@ typedef enum {
 	GGIT_DIFF_SHOW_UNMODIFIED            = 1u << 26,
 
 	GGIT_DIFF_PATIENCE                   = 1u << 28,
-	GGIT_DIFF_MINIMAL                    = 1u << 29
+	GGIT_DIFF_MINIMAL                    = 1u << 29,
+	GGIT_DIFF_SHOW_BINARY                = 1u << 30
 } GgitDiffOption;
 
 /**
@@ -546,12 +584,90 @@ typedef enum {
 } GgitMergeFileFavor;
 
 /**
- * GgitMergeTreeFlags:
- * @GGIT_MERGE_TREE_FIND_RENAMES: detect renames.
+ * GgitMergeFileFlags:
+ * GGIT_MERGE_FILE_DEFAULT: Defaults.
+ * GGIT_MERGE_FILE_STYLE_MERGE: Create standard conflicted merge files.
+ * GGIT_MERGE_FILE_STYLE_DIFF3: Create diff3-style files.
+ * GGIT_MERGE_FILE_SIMPLIFY_ALNUM: Condense non-alphanumeric regions for simplified diff file.
+ * GGIT_MERGE_FILE_IGNORE_WHITESPACE: Ignore all whitespace.
+ * GGIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE: Ignore changes in amount of whitespace.
+ * GGIT_MERGE_FILE_IGNORE_WHITESPACE_EOL: Ignore whitespace at end of line.
+ * GGIT_MERGE_FILE_DIFF_PATIENCE: Use the "patience diff" algorithm.
+ * GGIT_MERGE_FILE_DIFF_MINIMAL: Take extra time to find minimal diff.
  */
 typedef enum {
-	GGIT_MERGE_TREE_FIND_RENAMES = (1 << 0)
-} GgitMergeTreeFlags;
+	GGIT_MERGE_FILE_DEFAULT                  = 0,
+	GGIT_MERGE_FILE_STYLE_MERGE              = (1 << 0),
+	GGIT_MERGE_FILE_STYLE_DIFF3              = (1 << 1),
+	GGIT_MERGE_FILE_SIMPLIFY_ALNUM           = (1 << 2),
+	GGIT_MERGE_FILE_IGNORE_WHITESPACE        = (1 << 3),
+	GGIT_MERGE_FILE_IGNORE_WHITESPACE_CHANGE = (1 << 4),
+	GGIT_MERGE_FILE_IGNORE_WHITESPACE_EOL    = (1 << 5),
+	GGIT_MERGE_FILE_DIFF_PATIENCE            = (1 << 6),
+	GGIT_MERGE_FILE_DIFF_MINIMAL             = (1 << 7),
+} GgitMergeFileFlags;
+
+/**
+ * GgitMergeFlags:
+ * @GGIT_MERGE_FIND_RENAMES: detect renames that occur between the common
+ * ancestor and the "ours" side or the common ancestor and the "theirs" side.
+ * This will enable the ability to merge between a modified and renamed file.
+ * @GGIT_MERGE_FAIL_ON_CONFLICT: If a conflict occurs, exit immediately instead
+ * of attempting to continue resolving conflicts.  The merge operation will
+ * fail with @GGIT_EMERGECONFLICT and no index will be returned.
+ * @GGIT_MERGE_SKIP_REUC: do not write the REUC extension on the generated index.
+ * @GGIT_MERGE_NO_RECURSIVE: If the commits being merged have multiple merge bases,
+ * do not build a recursive merge base (by merging the multiple merge bases),
+ * instead simply use the first base.  This flag provides a similar
+ * merge base to `git-merge-resolve`.
+ */
+typedef enum {
+	GGIT_MERGE_FIND_RENAMES     = (1 << 0),
+	GGIT_MERGE_FAIL_ON_CONFLICT = (1 << 1),
+	GGIT_MERGE_SKIP_REUC        = (1 << 2),
+	GGIT_MERGE_NO_RECURSIVE     = (1 << 3)
+} GgitMergeFlags;
+
+/**
+ * GgitProxyType:
+ * @GGIT_PROXY_NONE: Do not attempt to connect through a proxy.
+ * @GGIT_PROXY_AUTO: Try to auto-detect the proxy from the git configuration.
+ * @GGIT_PROXY_SPECIFIED: Connect via the URL given in the options.
+ *
+ * The type of proxy to use.
+ */
+typedef enum {
+	GGIT_PROXY_NONE,
+	GGIT_PROXY_AUTO,
+	GGIT_PROXY_SPECIFIED
+} GgitProxyType;
+
+/**
+ * GgitRebaseOperationType:
+ * @GGIT_REBASE_OPERATION_PICK: The given commit is to be cherry-picked.
+ * The client should commit the changes and continue if there are no conflicts.
+ * @GGIT_REBASE_OPERATION_REWORD: The given commit is to be cherry-picked,
+ * but the client should prompt the user to provide an updated commit message.
+ * @GGIT_REBASE_OPERATION_EDIT: The given commit is to be cherry-picked,
+ * but the client should stop to allow the user to edit the changes before
+ * committing them.
+ * @GGIT_REBASE_OPERATION_SQUASH: The given commit is to be squashed into
+ * the previous commit. The commit message will be merged with the previous message.
+ * @GGIT_REBASE_OPERATION_FIXUP: The given commit is to be squashed into the
+ * previous commit. The commit message from this commit will be discarded.
+ * @GGIT_REBASE_OPERATION_EXEC: No commit will be cherry-picked.
+ * The client should run the given command and (if successful) continue.
+ *
+ * Type of rebase operation in-progress.
+ */
+typedef enum {
+	GGIT_REBASE_OPERATION_PICK = 0,
+	GGIT_REBASE_OPERATION_REWORD,
+	GGIT_REBASE_OPERATION_EDIT,
+	GGIT_REBASE_OPERATION_SQUASH,
+	GGIT_REBASE_OPERATION_FIXUP,
+	GGIT_REBASE_OPERATION_EXEC
+} GgitRebaseOperationType;
 
 /* NOTE: keep in sync with git2/refs.h */
 /**
@@ -688,7 +804,10 @@ typedef enum {
 	GGIT_STATUS_WORKING_TREE_MODIFIED   = 1 << 8,
 	GGIT_STATUS_WORKING_TREE_DELETED    = 1 << 9,
 	GGIT_STATUS_WORKING_TREE_TYPECHANGE = 1 << 10,
-	GGIT_STATUS_IGNORED                 = 1 << 14
+	GGIT_STATUS_WORKING_TREE_RENAMED    = 1 << 11,
+	GGIT_STATUS_WORKING_TREE_UNREADABLE = 1 << 12,
+	GGIT_STATUS_IGNORED                 = 1 << 14,
+	GGIT_STATUS_CONFLICTED              = 1 << 15,
 } GgitStatusFlags;
 
 /**
@@ -913,8 +1032,7 @@ typedef enum {
 	GGIT_DIFF_FIND_COPIES_FROM_UNMODIFIED     = (1u << 3),
 	GGIT_DIFF_FIND_REWRITES                   = (1u << 4),
 	GGIT_DIFF_BREAK_REWRITES                  = (1u << 5),
-	GGIT_DIFF_FIND_AND_BREAK_REWRITES         = (GGIT_DIFF_FIND_REWRITES |
-	                                             GGIT_DIFF_BREAK_REWRITES),
+	GGIT_DIFF_FIND_AND_BREAK_REWRITES         = (GGIT_DIFF_FIND_REWRITES | GGIT_DIFF_BREAK_REWRITES),
 	GGIT_DIFF_FIND_FOR_UNTRACKED              = (1u << 6),
 	GGIT_DIFF_FIND_ALL                        = (0x0ff),
 	GGIT_DIFF_FIND_IGNORE_LEADING_WHITESPACE  = 0,
@@ -1029,7 +1147,7 @@ typedef gint (* GgitDiffHunkCallback) (GgitDiffDelta *delta,
 /**
  * GgitDiffLineCallback:
  * @delta: a #GgitDiffDelta.
- * @hunk: a #GgitDiffHunk.
+ * @hunk: (nullable): a #GgitDiffHunk.
  * @line: a #GgitDiffLine.
  * @user_data: (closure): user-supplied data.
  *
@@ -1093,6 +1211,19 @@ typedef gint (* GgitNoteCallback) (GgitOId *blob_id,
 typedef gint (* GgitReferencesNameCallback) (const gchar *name,
                                              gpointer     user_data);
 
+/**
+ * GgitReferencesCallback:
+ * @reference: (transfer full): the reference.
+ * @user_data: (closure): user-supplied data.
+ *
+ * The type of the callback functions for retrieving the references
+ * in a #GgitRepository. See ggit_repository_references_foreach().
+ *
+ * Returns: 0 to go for the next references or a #GgitError in case there was an error.
+ */
+typedef gint (* GgitReferencesCallback) (GgitRef  *reference,
+                                         gpointer  user_data);
+
 /**
  * GgitRemoteListCallback:
  * @name: the name of the reference.
